==> kolourpaint-16.11.80.tar.xz: kolourpaint-16.11.80/commands/tools/kpToolColorPickerCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpToolColorPickerCommand_H
#define kpToolColorPickerCommand_H


#include "imagelib/kpColor.h"
#include "commands/kpCommand.h"


class kpToolColorPickerCommand : public kpCommand
{
public:
    kpToolColorPickerCommand (int mouseButton,
                              const kpColor &newColor, const kpColor &oldColor,
                              kpCommandEnvironment *environ);
    virtual ~kpToolColorPickerCommand ();

    virtual QString name () const;

    virtual SizeType size () const;

    virtual void execute ();
    virtual void unexecute ();

private:
    int m_mouseButton;
    kpColor m_newColor;
    kpColor m_oldColor;
};


#endif  // kpToolColorPickerCommand_H

==> kolourpaint_17.12.3.orig.tar.xz: kolourpaint-17.12.3/commands/tools/kpToolColorPickerCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpToolColorPickerCommand_H
#define kpToolColorPickerCommand_H


#include "imagelib/kpColor.h"
#include "commands/kpCommand.h"


class kpToolColorPickerCommand : public kpCommand
{
public:
    kpToolColorPickerCommand (int mouseButton,
                              const kpColor &newColor, const kpColor &oldColor,
                              kpCommandEnvironment *environ);
    virtual ~kpToolColorPickerCommand ();

    QString name () const Q_DECL_OVERRIDE;

    SizeType size () const Q_DECL_OVERRIDE;

    void execute () Q_DECL_OVERRIDE;
    void unexecute () Q_DECL_OVERRIDE;

private:
    int m_mouseButton;
    kpColor m_newColor;
    kpColor m_oldColor;
};


#endif  // kpToolColorPickerCommand_H
